#
# kihonb.rb
#   $Id$
#


require "numru/dcl"
include NumRu
include Math


nmax = 9
y = NArray.sfloat(nmax)

#-- graph ---
iws = (ARGV[0] || (puts ' WORKSTATION ID (I)  ? ;'; DCL::sgpwsn; gets)).to_i
DCL::sgopn iws

DCL::sgfrm

x1 = 0.1
x2 = 0.9
xc = 0.5

#--  ----
for n in 1..nmax
  y[n-1] = 0.1*(10-n)
  DCL::sglnv(x1, y[n-1], x2, y[n-1])
end

DCL::sglnv(xc, 0.05, xc, 0.95)

#-- ǥե ----
DCL::sgtxv(xc, y[0], 'SGTXV\^{SUP}RST\_{SUB}')

#-- ź ----
DCL::sglset('LCNTL', true)
DCL::sgtxv(xc, y[1], 'SSGTXV\^{SUP}RST\_{SUB}')

DCL::sgrset('SMALL', 0.5)
DCL::sgrset('SHIFT', 0.5)
DCL::swlset('LSYSFNT', true)
DCL::sgtxv(xc, y[2], 'S\o-G\o~T\u-X\o~\u-V\^{SUP}RST\_{SUB}')
DCL::swlset('LSYSFNT', false)

#-- ե ----
DCL::sgtxv(xc, y[3], 'ABCDEFG abcdefg')

DCL::sgiset('IFONT', 2)
DCL::sgtxv(xc, y[4], 'ABCDEFG abcdefg')

DCL::sgstxi(3)
DCL::sgtxv(xc, y[5], 'ABCDEFG abcdefg')

DCL::sgiset('IFONT', 1)
DCL::sgstxi(1)

#-- ꥷʸ ----
greek1 = DCL::usgi(128) + DCL::usgi(129) + DCL::usgi(130) + DCL::usgi(131) + DCL::usgi(132) +
         DCL::usgi(133) + DCL::usgi(134) + DCL::usgi(135) + DCL::usgi(136) + DCL::usgi(137)
greek2 = DCL::usgi(152) + DCL::usgi(153) + DCL::usgi(154) + DCL::usgi(155) + DCL::usgi(156) +
         DCL::usgi(157) + DCL::usgi(158) + DCL::usgi(159) + DCL::usgi(160) + DCL::usgi(161)

DCL::sgtxv(xc, y[6], greek1)
DCL::sgtxv(xc, y[7], greek2)

#-- ü쵭 ----
symbol = DCL::usgi(189) + DCL::usgi(190) + DCL::usgi(191) + DCL::usgi(192) + DCL::usgi(193) +
         DCL::usgi(210) + DCL::usgi(211) + DCL::usgi(212) + DCL::usgi(217) + DCL::usgi(218)

DCL::sgtxv(xc, y[8], symbol)

DCL::sgcls

